NAME

WebService::GData::Feed::Link - Represent an xml Link tag.

SYNOPSIS

 use WebService::GData::Feed;
 
 my $feed = new WebService::GData::Feed($jsonfeed);
 
my $links=  $feed->links();

foreach my $link (@$links){
    #print $link->rel,$link->type, $link->href;
}

DESCRIPTION

inherits from WebService::GData::Feed

This package wraps the link data found in a feed using the json format of the Google Data API v2 (no other format is supported!).

CONSTRUCTOR

new

Accept the content of the link tag from a feed that has been perlified (from_json($json_string)).

Parameters

Returns

Throws

WebService::GData::Error - invalid_parameter_type if it is not an hash reference.

Example:

use WebService::GData::Feed::Link;

my $link = new WebService::GData::Feed::Link($jsonfeed->{link}->[0]);

#or
my $link = new WebService::GData::Feed::Link({
    rel =>"alternate",
    type => "text/html",
    href => "http://www.youtube.com"
});    

$link->rel();#alternate

GET/SET METHODS

name

get/set the name of the author.

Parameters

none - as a getter
name:Scalar as a setter

Returns

none - as a setter
name:Scalar as a getter

Example:

use WebService::GData::Feed::Author;

my $author = new WebService::GData::Feed::Author($jsonfeed->{author}->[0]);

$feed->name("john");

$feed->name();#john

uri

get/set the uri of the author.

Parameters

none - as a getter
uri:Scalar as a setter

Returns

none - as a setter
uri:Scalar as a getter

Example:

use WebService::GData::Feed::Author;

my $author = new WebService::GData::Feed::Author($jsonfeed->{author}->[0]);

$feed->uri("http://www.youtube.com/john");

$feed->uri();#"http://www.youtube.com/john"

BUGS AND LIMITATIONS

If you do me the favor to _use_ this module and find a bug, please email me i will try to do my best to fix it (patches welcome)!

AUTHOR

shiriru <shirirulestheworld[arobas]gmail.com>

LICENSE AND COPYRIGHT

This library is free software; you can redistribute it and/or modify it under the same terms as Perl itself.